==> ecs-1.100.0-sources.jar: software/amazon/awscdk/services/ecs/BottleRocketImage.java <==
package software.amazon.awscdk.services.ecs;

/**
 * Construct an Bottlerocket image from the latest AMI published in SSM.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:41.758Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.BottleRocketImage")
public class BottleRocketImage extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.IMachineImage {

    protected BottleRocketImage(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected BottleRocketImage(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Constructs a new instance of the BottleRocketImage class.
     * <p>
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public BottleRocketImage(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.BottleRocketImageProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { props });
    }

    /**
     * Constructs a new instance of the BottleRocketImage class.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public BottleRocketImage() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Return the correct image.
     * <p>
     * @param scope This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.MachineImageConfig getImage(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope) {
        return software.amazon.jsii.Kernel.call(this, "getImage", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.MachineImageConfig.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required") });
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.ecs.BottleRocketImage}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.ecs.BottleRocketImage> {
        /**
         * @return a new instance of {@link Builder}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create() {
            return new Builder();
        }

        private software.amazon.awscdk.services.ecs.BottleRocketImageProps.Builder props;

        private Builder() {
        }

        /**
         * The Amazon ECS variant to use.
         * <p>
         * Only <code>aws-ecs-1</code> is currently available
         * <p>
         * Default: - BottlerocketEcsVariant.AWS_ECS_1
         * <p>
         * @return {@code this}
         * @param variant The Amazon ECS variant to use. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder variant(final software.amazon.awscdk.services.ecs.BottlerocketEcsVariant variant) {
            this.props().variant(variant);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.ecs.BottleRocketImage}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.ecs.BottleRocketImage build() {
            return new software.amazon.awscdk.services.ecs.BottleRocketImage(
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.services.ecs.BottleRocketImageProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.services.ecs.BottleRocketImageProps.Builder();
            }
            return this.props;
        }
    }
}

==> ecs-1.122.0-sources.jar: software/amazon/awscdk/services/ecs/BottleRocketImage.java <==
package software.amazon.awscdk.services.ecs;

/**
 * Construct an Bottlerocket image from the latest AMI published in SSM.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.34.0 (build 9b72778)", date = "2021-09-08T20:44:44.440Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.BottleRocketImage")
public class BottleRocketImage extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.IMachineImage {

    protected BottleRocketImage(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected BottleRocketImage(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Constructs a new instance of the BottleRocketImage class.
     * <p>
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public BottleRocketImage(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.BottleRocketImageProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { props });
    }

    /**
     * Constructs a new instance of the BottleRocketImage class.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public BottleRocketImage() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Return the correct image.
     * <p>
     * @param scope This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.MachineImageConfig getImage(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope) {
        return software.amazon.jsii.Kernel.call(this, "getImage", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.MachineImageConfig.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required") });
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.ecs.BottleRocketImage}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.ecs.BottleRocketImage> {
        /**
         * @return a new instance of {@link Builder}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create() {
            return new Builder();
        }

        private software.amazon.awscdk.services.ecs.BottleRocketImageProps.Builder props;

        private Builder() {
        }

        /**
         * The CPU architecture.
         * <p>
         * Default: - x86_64
         * <p>
         * @return {@code this}
         * @param architecture The CPU architecture. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder architecture(final software.amazon.awscdk.services.ec2.InstanceArchitecture architecture) {
            this.props().architecture(architecture);
            return this;
        }

        /**
         * The Amazon ECS variant to use.
         * <p>
         * Only <code>aws-ecs-1</code> is currently available
         * <p>
         * Default: - BottlerocketEcsVariant.AWS_ECS_1
         * <p>
         * @return {@code this}
         * @param variant The Amazon ECS variant to use. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder variant(final software.amazon.awscdk.services.ecs.BottlerocketEcsVariant variant) {
            this.props().variant(variant);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.ecs.BottleRocketImage}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.ecs.BottleRocketImage build() {
            return new software.amazon.awscdk.services.ecs.BottleRocketImage(
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.services.ecs.BottleRocketImageProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.services.ecs.BottleRocketImageProps.Builder();
            }
            return this.props;
        }
    }
}
